@@ -6,8 +6,8 @@
 #   package
 #
 # $Source: /sources/cvsrepos/majordomo/contrib/archive_mh.pl,v $
-# $Revision: 1.3 $
-# $Date: 1996/12/09 16:50:37 $
+# $Revision: 1.4 $
+# $Date: 1997/03/10 15:40:41 $
 # $Author: cwilson $
 # $State: Exp $
 #
@@ -26,7 +26,7 @@ if ($ARGV[0] eq "-C") {
 if (! -r $cf) {
     die("$cf not readable; stopped");
 }
-reqiure "$cf"; 
+require "$cf"; 
 
 # Go to the home directory specified by the .cf file
 chdir("$homedir");
