@@ -1,19 +1,19 @@
 # General subroutines for Majordomo
 
 # $Source: /sources/cvsrepos/majordomo/majordomo.pl,v $
-# $Revision: 1.52 $
-# $Date: 1996/12/23 15:03:52 $
+# $Revision: 1.56 $
+# $Date: 1997/08/27 14:58:53 $
 # $Author: cwilson $
 # $State: Exp $
 # 
-# $Header: /sources/cvsrepos/majordomo/majordomo.pl,v 1.52 1996/12/23 15:03:52 cwilson Exp $
+# $Header: /sources/cvsrepos/majordomo/majordomo.pl,v 1.56 1997/08/27 14:58:53 cwilson Exp $
 # 
 
 # The exit codes for abort.  Look in /usr/include/sysexits.h.
 #
 $EX_DATAERR = 65;
 $EX_TEMPFAIL = 75;
-
+$EX_NOUSER = 67;
 
 package Majordomo;
 
@@ -94,7 +94,7 @@ sub main'RetMailAddr  ## Public
 sub main'ParseAddrs {
     local($_) = shift;
     1 while s/\([^\(\)]*\)//g; 		# strip comments
-    1 while s/"[^"]*"//g;		# strip comments"
+    1 while s/"[^"]*"\s//g;		# strip comments"
     split(/,/);				# split into parts
     foreach (@_) {
 	1 while s/.*<(.*)>.*/$1/;
@@ -301,7 +301,8 @@ sub main'check_permissions {
     local($err);
     if ( ! -w $log_file ) {
 	if ( ! -e $log_file ) {			# log file may not exist, check dir perms.
-	    local($dir) = $log_file =~ m@^(/\S+/)@;
+	    local($dir);
+	    ($dir) = $log_file =~ m@^(/\S+)/@;
 	    if ( ! -w $dir ) {
 		$err .= "Unable to create log file in $dir, check permissions.\n"; # 
 	    }
@@ -515,8 +516,8 @@ sub main'valid_addr {
     # Deal with unbalanced brackets or parenthesis in an address.
     $temp = $_;
 
-    # Nuke anything within quotes.  Placate Emacs -------v 
-    1 while $temp =~ s/(^|([^\\\"]|\\.)+)\"([^\\\"]|\\.|$)*\"?/$1/g;
+    # Nuke anything within quotes.
+    1 while $temp =~ s/(^|([^\\\"]|\\.)+)\"(([^\\\"]|\\.)*|$)\"?/$1/g;
 
     # Remove nested parentheses " <- placate emacs' highlighting
     1 while $temp =~ s/\([^\(\)]*\)//g;
@@ -706,28 +707,32 @@ sub main'fileglob {
 }
 
 sub main'is_list_member {
-    local($subscriber, $listdir, $clean_list) = @_;
-    local($matches);
+    local($subscriber, $listdir, $clean_list, $file) = @_;
+    local($matches) = 0;
     local(*LIST);
     local($_);
 
     print STDERR "is_list_member: enter\n" if $DEBUG;
 
-    open(LIST, "$listdir/$clean_list")
-	|| &main'abort("Can't read $listdir/$clean_list: $!"); #'"";
-
-    print STDERR "is_list_member: checking $listdir/$clean_list for $subscriber\n"
-	  if $DEBUG; 
-
-    while (<LIST>) {
-	if (&main'addr_match($subscriber, $_, 
-	   (&main'cf_ck_bool($clean_list,"mungedomain") ? 2 : undef))) {
-	    $matches++;
+    $file = "$listdir/$file" if defined $file && $file !~ m|^/|;
+    $file = "$listdir/$clean_list" unless defined $file;
+    print STDERR "is_list_member: checking $file for $subscriber\n"
+	if $DEBUG; 
+    if (open(LIST, $file)) {
+	while (<LIST>) {
+	    if (&main'addr_match($subscriber, $_, 
+	       (&main'cf_ck_bool($clean_list,"mungedomain") ? 2 : undef))) {
+		$matches++;
+		last;
+	    }
 	}
+	close(LIST);
+    }
+    else {
+	&main'bitch("Can't read $file: $!"); #'"";
     }
-    close(LIST);
 
-    print STDERR "is_list_member: exit\n" if $DEBUG;
+    print STDERR "is_list_member: exit $matches\n" if $DEBUG;
 
     return($matches);
 }
@@ -783,7 +788,8 @@ sub main'access_check {
         } else {
             $altlist = "$clean_list-digest";
         }
-        @lists = ($clean_list,$altlist);
+        @lists = ($clean_list);
+	push(@lists, $altlist) if -e "$listdir/$altlist";
     }
 
     print STDERR "access_check: checking lists " , join(', ', @lists), "\n" 
@@ -791,8 +797,7 @@ sub main'access_check {
 
     $total = 0;
     foreach $list (@lists) {
-        next unless (-e "$listdir/$list");
-        $total += &main'is_list_member($subscriber, $listdir, $list);
+	$total += &main'is_list_member($subscriber, $listdir, $clean_list, $list);
     }
     print STDERR "access_check: exit\n" if $DEBUG;
     return $total;
